import React from 'react';
import { Tree } from 'antd';
import { getDept } from '@/services/sysDept';
import { arr2Tree } from '@/utils/array';

export default React.forwardRef((props, ref) => {
  const { onList, expandAll = true, ...leftProps } = props;

  const [list, setList] = React.useState([]);
  const [expandedKeys, setExpandedKeys] = React.useState([]);

  const treeData = React.useMemo(() => {    
    const stdList = list.map(x => ({ ...x, key: x.deptId, title: x.deptName }))
    const [tree] = arr2Tree(stdList)
    return tree;
  }, [list])

  const queryData = React.useCallback(() => {
    getDept({ pageSize: 999 }).then(res => {
      const records = res.records || [];
      setList(records);
    })
  }, []);

  React.useEffect(() => {
    queryData();
  }, [])
  
  React.useEffect(() => {
    if (expandAll) {
      setExpandedKeys(list.map(x => x.deptId))
    }
  }, [expandAll, list])

  React.useEffect(() => {
    if (onList) {
      onList(list);
    }
  }, [list])

  React.useImperativeHandle(ref, () => ({
    reload: queryData,
  }));

  return (
    <Tree
      style={{ width: '100%' }}
      defaultExpandAll={expandAll}
      expandedKeys={expandedKeys}
      onExpand={setExpandedKeys}
      {...leftProps}
      treeData={treeData}
    />
  )
})
