import React from 'react';
import { Button, Popconfirm, message } from 'antd';
import { ProTable } from '@ant-design/pro-components';
import AuthWrapper from '@/components/Auth';
import AuthButton from '@/components/Auth/AuthButton';
import AuthDanger from '@/components/Auth/AuthDanger';

import useRequest from './useRequest';
// import ExportBtn from './components/ExportBtn';

export default React.forwardRef((props, ref) => {
  /**
   * request 与 ProTable 定义不同，这个只是普通的接口即可
   */
  const {
    request,
    exportFunc,
    columns,
    authCode,
    operateWidth = 200,
    onAdd,
    onDelete,
    onEdit,
    toolBarRender,
    columnOptionRender,
    options=false,
    ...leftProps
  } = props;

  const actionRef = React.useRef();
  const hideRef = React.useRef();
  const [fullParams, newReq] = useRequest(request);

  // 统一实现操作列
  const cols = React.useMemo(() => [
    ...columns,
    operateWidth < 1 ? false : {
      title: '操作',
      key: 'option',
      width: operateWidth,
      fixed: 'right',
      search: false,
      render: (_, record) => [
        (
          onEdit &&
          <AuthButton
            key="edit"
            type="link"
            code={authCode?.edit}
            style={{ paddingRight: 20 }}
            onClick={() => onEdit(record)}
          >
            编辑
          </AuthButton>
        ),
        (
          onDelete &&
          <AuthDanger
            key="delete"
            code={authCode?.delete}
            onClick={() => onDelete(record)}
          >
            删除
          </AuthDanger>
        ),
        ...(columnOptionRender ? columnOptionRender(_, record) : []),
      ].filter(Boolean),
    },
  ].filter(x => x !== false), [columns, onEdit, onDelete]);

  React.useImperativeHandle(ref, () => {
    const showLoading = msg => (hideRef.current = message.loading(msg || '操作中, 请稍候...'));
    const hideLoading = () => hideRef.current && hideRef.current();
    const reload = () => actionRef.current?.reload && actionRef.current.reload();

    return {
      showLoading,
      hideLoading,
      reload,
      actionRef: actionRef,
    }
  }, []);

  return (
    <ProTable
      columns={cols}
      request={newReq}
      cardBordered
      actionRef={actionRef}
      options={options}
      toolBarRender={() => [
        (
          onAdd ? (
            <AuthButton
              key="add"
              type="primary"
              code={authCode?.add}
              onClick={onAdd}
            >
              新增
            </AuthButton>
          ) : false
        ),
        // (
        //   exportFunc ? (
        //     <ExportBtn
        //       key="export"
        //       authCode={authCode?.export}
        //       params={fullParams}
        //       request={exportFunc}
        //     />
        //   ) : false
        // ),
        ...(toolBarRender ? toolBarRender() : []),
      ].filter(Boolean)}
      {...leftProps}
    />
  )
});