import React from "react";

export default function useRequest(req) {
  const [fullParams, setFullParams] = React.useState();

  const newReq = React.useCallback((params, sort, filter) => {
    let sortParam = {}
    const sortKeys = Object.keys(sort || {});
    if (sortKeys.length > 0) {
      const sortKey = sortKeys[0];
      const sortValue = sort[sortKey];

      if (sortValue) {
        if (sortValue.includes('asc')) {
          Object.assign(sortParam, { 'sortAsc': sortKey })
        } else {
          Object.assign(sortParam, { 'sortDesc': sortKey })
        }
      }
    }

    const ps = {
      ...params,
      pageNum: params.current,
      ...sortParam,
    }
    
    setFullParams(ps);
    
    return req(ps)
      .then((res) => {
        return {
          data: res.records,
          success: true,
          total: res.total,
        };
      })
      .catch((err) => {
        return {
          success: false,
        };
      });
  }, [req]);

  return [fullParams, newReq];
}
