import React, { useMemo, useState } from "react";
import { Button, Card, Form, Input, Select } from "antd";
import useBool from "@/utils/hooks/useBool";
import { useSearchParams, useNavigate } from "react-router-dom";
import Page from "@/components/Page";
import { formItemLayout, tailFormItemLayout } from "@/utils/form";
import {
  postSysUser,
  putSysUser,
  getSysUserById,
  getRestPaw,
  getRestSts,
} from "@/services/sysUser";
import { getDept } from "@/services/sysDept";
import { getRole } from "@/services/sysrole";
import { queryDict } from "@/utils/request";
const { Option } = Select;

export default (props) => {
  const [loading, startLoading, cancelLoading] = useBool();
  const [submiting, startSubmit, cancelSubmit] = useBool();

  const [searchParams] = useSearchParams();
  const [deptOption, setDept] = useState([]);
  const [roleOption, setRole] = useState([]);
  const [onSelect, setOnSelect] = useState([]);
  const [form] = Form.useForm();
  const navigate = useNavigate();

  const id = searchParams.get("id");

  React.useEffect(() => {
    getDept().then((res) => {
      const data = (res.records || []).map((it) => {
        return {
          ...it,
          label: it.deptName,
          value: it.deptId,
        };
      });
      setDept(data);
    });
  }, []);

  React.useEffect(() => {
    getRole().then((res) => {
      const data = (res.records || []).map((it) => {
        return {
          label: it.roleName,
          value: it.roleId,
          roleName: it.roleName,
          roleId: it.roleId,
        };
      });
      setRole(data);
    });
  }, []);

  React.useEffect(() => {
    if (id) {
      getSysUserById(id).then((res) => {
        const roleList = res.roleList.map((it) => {
          return {
            label: it.roleName,
            value: it.roleId,
            roleName: it.roleName,
            roleId: it.roleId,
          };
        });
        console.log(roleList);

        form.setFieldsValue({
          ...res,
          roleList: roleList,
        });
      });
    }
  }, []);

  const onFinish = (values) => {
    startSubmit();
  
    const roleList = (values.roleList || []).map((it) => {
      return {
        roleName: it.label,
        roleId: it.value,
      };
    });
    const data = {
      ...values,
      roleList: roleList,
      userId:id||""
    };
    console.log(data)

    //新增//修改
    postSysUser(data)
      .then((res) => {
        cancelSubmit();
        navigate(-1);
      })
      .catch(() => {
        cancelSubmit();
      });
  };

  return (
    <Page>
      <Card loading={loading}>
        <Form
          onFinish={onFinish}
          form={form}
          {...formItemLayout}
          scrollToFirstError
          style={{ maxWidth: "1000px" }}
        >
          <Form.Item
            name="userName"
            label="用户名称"
            rules={[
              {
                required: true,
                message: "用户名称不为空",
              },
            ]}
          >
            <Input placeholder="请输入用户名称" />
          </Form.Item>
          <Form.Item
            name="phone"
            label="手机号"
            // rules={[
            //   {
            //     required: true,
            //     message: "请填写税号",
            //   },
            // ]}
          >
            <Input placeholder="请输入手机号" />
          </Form.Item>

          <Form.Item name="deptId" label="部门">
            <Select placeholder="请选择部门" options={deptOption} />
          </Form.Item>

          <Form.Item name="roleList" label="角色名称">
            <Select
              labelInValue
              name="userId"
              mode="multiple"
              placeholder="请选择"
              options={roleOption}
              onChange={(v, option) => setOnSelect(option)}
            />
          </Form.Item>
          <Form.Item {...tailFormItemLayout}>
            <Button loading={submiting} type="primary" htmlType="submit">
              保存
            </Button>
            <Button style={{ marginLeft: "2em" }} onClick={() => navigate(-1)}>
              返回
            </Button>
          </Form.Item>
        </Form>
      </Card>
    </Page>
  );
};
