import React from "react";
import { useNavigate } from "react-router-dom";
import { Button, Popconfirm, message } from "antd";
import { ProTable } from "@ant-design/pro-components";
import { queryTable } from "@/utils/request";
import { getSysUser, deleteSysUser } from "@/services/sysUser";
import Page from "@/components/Page";
import List from "@/components/Page/List";
import moment from "moment";

// const userList = queryTable(getSysUser);

export default (props) => {
  const actionRef = React.useRef();
  const navigate = useNavigate();

  const handleDelete = (id) => {
    deleteSysUser(id).then((res) => {
      actionRef.current.reload();
    });
  };

  const columns = [
    {
      title: "用户名称",
      dataIndex: "userName",
    },
    {
      title: "手机号",
      dataIndex: "phone",
    },
    // {
    //   title: "标签",
    //   dataIndex: "tag",
    //   search: false,
    // },
    {
      title: "状态",
      dataIndex: "status",
      render: (_,row) => (row.status == 0 ? "未激活" : row.status == 1 ? "已激活" : "停用"),
      valueEnum: {
        0: "未激活",
        1: "已激活",
        2: "停用",
      },
    },

    {
      title: "创建时间",
      dataIndex: "createdAt",
      search: false,
      render: (_,row)=>row.createdAt?moment(row.createdAt).format("YYYY-MM-DD HH:mm:ss"):""
    },
   
    // {
    //   title: "更新时间",
    //   dataIndex: "updatedAt",
    //   search: false,
    //   render: (_,row)=>row.updatedAt?moment(row.updatedAt).format("YYYY-MM-DD HH:mm:ss"):""
    // },
  ];

  return (
    <List
      actionRef={actionRef}
      rowKey="userId"
      onEdit={(record) => navigate(`/aduser/edit?id=${record.userId}`)}
      onDelete={(record) => handleDelete(record.userId)}
      toolBarRender={() => [
        <Button
          key="1"
          type="primary"
          onClick={() => {
            navigate("/aduser/edit");
          }}
        >
          新增
        </Button>,
      ]}
      request={getSysUser}
      columns={columns}
    />
  );
};
