import React, { useRef, useState } from 'react'
import { Button, Card, Form, Input, Select, Row, Col, Radio } from 'antd'
import {
  ProForm,
  ProFormDateTimeRangePicker,
  ProFormMoney,
  ProFormSelect,
  ProFormText,
  ProFormRadio,
} from "@ant-design/pro-components";
import useBool from "@/utils/hooks/useBool";
import { useSearchParams, useNavigate } from "react-router-dom";
import Page from "@/components/Page";
import { formItemLayout, tailFormItemLayout } from "@/utils/form";
import { postTaCustom, putTaCustom, getTaCustomId } from "@/services/taCustom";
const { Option } = Select;

export default (props) => {
  const formRef = useRef();
  const [submiting, startSubmit, cancelSubmit] = useBool();

  const [searchParams] = useSearchParams()
  const navigate = useNavigate()
  const [isOrg, setIsOrg] = useState(0)

  const id = searchParams.get("id");

  React.useEffect(() => {
    if (id) {
      getTaCustomId(id).then((res) => {
        formRef.current?.setFieldsValue(res);
      });
    }
  })
  const onChange = (e) => {
    setIsOrg(e.target.value)
  }

  const onFinish = (values) => {
    startSubmit()
    let dutyParagraph = values?.isOrg
    if (isOrg == 0) {
      dutyParagraph = null
    }
    if (id) {
      //修改
      const customId = id
      putTaCustom(id, { customId, dutyParagraph, ...values })
        .then((res) => {
          cancelSubmit();
          navigate(-1);
        })
        .catch(() => {
          cancelSubmit();
        });
    } else {
      //新增
      postTaCustom({ dutyParagraph, ...values })
        .then((res) => {
          cancelSubmit();
          navigate(-1);
        })
        .catch(() => {
          cancelSubmit();
        });
    }
  };

  return (
    <Page>
      <Card>
        <ProForm
          formRef={formRef}
          onFinish={onFinish}
          layout="horizontal"
          {...formItemLayout}
          initialValues={{ isOrg: 0 }}
          submitter={{
            render: (_, doms) => [
              <Row>
                <Col offset={8}>
                  <Button type="primary" htmlType="submit">
                    提交
                  </Button>
                </Col>
                <Col offset={1}>
                  <Button onClick={() => navigate(-1)}>返回</Button>
                </Col>
              </Row>,
            ],
          }}
        >
          <ProFormText name="customName" label="客户名" />
          {isOrg != 0 && <ProFormText name="dutyParagraph" label="客户税号" />}
          <ProFormText name="openingBank" label="开户行" />
          <ProFormText name="account" label="客户账号" />
          <ProFormText name="contactsName" label="联系人姓名" />
          <ProFormText name="contactsTitle" label="联系人头衔" />
          <ProFormText
            name="contactsPhone"
            label="联系人手机"
            maxlength={11}
            type="number"
          />
          <ProFormText name="contactsEmail" label="联系人邮箱" />
          <Form.Item label="是否企业">
            <Radio.Group onChange={onChange} value={isOrg} name="isOrg">
              <Radio value={0}>否</Radio>
              <Radio value={1}>是</Radio>
            </Radio.Group>
          </Form.Item>
        </ProForm>
      </Card>
    </Page>
  );
};
