import React, { useEffect } from "react";
import { useNavigate } from "react-router-dom";
import { Button, Popconfirm, message } from "antd";
import { ProTable } from "@ant-design/pro-components";
import { queryTable } from "@/utils/request";
import { getTaCustom, deleteTaCustom } from "@/services/taCustom";
import Page from "@/components/Page";
import List from "@/components/Page/List";
import {
  postTaMemberCardIdActive,
  putTaMemberCardIdWrite,
} from "@/services/taMemberCard";

export default (props) => {
  const actionRef = React.useRef();
  const navigate = useNavigate();

  const handleDelete = (id) => {
    if (id) {
      deleteTaCustom(id).then((res) => {
        actionRef.current.reload();
      });
    }
  };

  const columns = [
    {
      title: "客户名",
      dataIndex: "customName",
      ellipsis: true,
    },
    {
      title: "税号",
      dataIndex: "dutyParagraph",
      ellipsis: true,
      search: false,
    },
    {
      title: "开户行",
      dataIndex: "openingBank",
      ellipsis: true,
    },
    {
      title: "账号",
      dataIndex: "account",
      ellipsis: true,
    },
    {
      title: "联系人姓名",
      dataIndex: "contactsName",
      ellipsis: true,
    },
    {
      title: "联系人头衔",
      dataIndex: "contactsTitle",
      ellipsis: true,
      search: false,
    },
    // {
    //   title: '状态',
    //   dataIndex: 'status',
    //   ellipsis: true,
    // },
    {
      title: "联系人手机",
      dataIndex: "contactsPhone",
      ellipsis: true,
    },
    {
      title: "联系人邮箱",
      dataIndex: "contactsEmail",
      search: false,
      ellipsis: true,
    },
    {
      title: "是否企业",
      dataIndex: "isOrg",
      ellipsis: true,
      valueType: "select",
      valueEnum: {
        0: "否",
        1: "是",
      },
    },
    // {
    //   title: '租户号',
    //   dataIndex: 'tenantId',
    //   ellipsis: true,
    // },
    // {
    //   title: '创建人',
    //   dataIndex: 'createdBy',
    //   ellipsis: true,
    //   search: false,
    // },
  ];


  return (
    <List
      actionRef={actionRef}
      rowKey="customId"
      onDelete={(record) => handleDelete(record?.customId)}
      onEdit={(record) => navigate(`/custom/edit?id=${record?.customId}`)}
      toolBarRender={() => [
        <Button
          key="1"
          type="primary"
          onClick={() => {
            navigate("/custom/edit");
          }}
        >
          新增
        </Button>,
      ]}
      request={getTaCustom}
      columns={columns}
    />
  );
};
