import React, { useEffect, useRef, useState, forwardRef } from 'react'
import {
  postTfFinance,
  putTfFinance,
  getTfFinanceId,
} from '@/services/tfFinance'
import { Button, Card, Row, Col, Form, Input } from 'antd'
import {
  ProForm,
  ProFormDateTimeRangePicker,
  ProFormMoney,
  ProFormSelect,
  ProFormText,
  ProFormTextArea,
  ProFormRadio,
} from '@ant-design/pro-components'
import Page from '@/components/Page'
import { formItemLayout, tailFormItemLayout } from '@/utils/form'
import { useNavigate, useSearchParams } from 'react-router-dom'
import moment from 'moment'

export default (props) => {
  const formRef = useRef()
  const navigate = useNavigate()

  const [params] = useSearchParams()
  const id = params.get('id')

  useEffect(() => {
    if (id) {
      getTfFinanceId(id).then((res) => {
        formRef.current?.setFieldsValue(res)
      })
    }
  }, [])

  const onFinish = (values) => {
    if (!id) {
      postTfFinance(values).then((res) => {
        navigate(-1)
      })
    } else if (id) {
      let financeId = id
      putTfFinance(id, { financeId, ...values }).then((res) => {
        navigate(-1)
      })
    }
  }

  let formatter = new Intl.NumberFormat('zh-CN', {
    minimumFractionDigits: 4,
    maximumFractionDigits: 4,
  })

  return (
    <Page>
      <Card>
        <ProForm
          formRef={formRef}
          onFinish={onFinish}
          layout="horizontal"
          initialValues={{ bizStatus: '1' }}
          {...formItemLayout}
          // grid={true}
          submitter={{
            render: (_, doms) => [
              <Row>
                <Col offset={8}>
                  <Button type="primary" htmlType="submit">
                    提交
                  </Button>
                </Col>
                <Col offset={1}>
                  <Button onClick={() => navigate(-1)}>返回</Button>
                </Col>
              </Row>,
            ],
          }}
        >
          <ProFormText name="financeName" label="记录名称" />
          <ProFormMoney name="totalCharges" label="总费用" />
          <ProFormMoney name="grossProfits" label="毛利润" />
          <ProFormMoney name="totalCost" label="总成本" />
          <ProFormMoney name="expense" label="已支出" />
          <ProFormMoney name="received" label="已收款" />
          <ProFormMoney name="balancePayment" label="尾款" />
          <ProFormMoney name="invoice" label="发票" />
          <ProFormRadio.Group
            name="bizStatus"
            label="项目状态"
            options={[
              { label: '正常', value: '1' },
              { label: '禁用', value: '0' },
            ]}
          />
        </ProForm>
      </Card>
    </Page>
  )
}
