import List from '@/components/Page/List'
import React, { useRef } from 'react'
import { getTfFinance, deleteTfFinance } from '@/services/tfFinance'
import { queryDict } from '@/utils/request'
import { Button, ConfigProvider } from 'antd'
import { ProFormDateTimeRangePicker } from '@ant-design/pro-components'
import { useNavigate } from 'react-router-dom'

export default (props) => {
  const navigate = useNavigate()

  const columns = [
    {
      title: '记录名称',
      dataIndex: 'financeName',
      ellipsis: true,
    },
    {
      title: '项目状态',
      dataIndex: 'bizStatus',
      valueEnum: {
        1: '正常',
        0: '禁用',
      },
      search: false,
      ellipsis: true,
    },
    {
      title: '总费用',
      dataIndex: 'totalCharges',
      search: false,
      ellipsis: true,
    },
    {
      title: '毛利润',
      dataIndex: 'grossProfits',
      search: false,
      ellipsis: true,
    },
    {
      title: '总成本',
      dataIndex: 'totalCost',
      search: false,
      ellipsis: true,
    },
    {
      title: '已支出',
      dataIndex: 'expense',
      search: false,
      ellipsis: true,
    },
    {
      title: '已收款',
      dataIndex: 'received',
      search: false,
      ellipsis: true,
    },
    {
      title: '尾款',
      dataIndex: 'balancePayment',
      search: false,
      ellipsis: true,
    },
    {
      title: '发票',
      dataIndex: 'invoice',
      search: false,
      ellipsis: true,
    },
  ]

  const actionRef = useRef()
  const onAdd = () => {
    navigate('/finance/edit')
  }
  return (
    <List
      actionRef={actionRef}
      rowKey="financeId"
      onEdit={(record) => navigate(`/finance/edit?id=${record?.financeId}`)}
      onDelete={(record) =>
        deleteTfFinance(record?.financeId).then(() =>
          actionRef.current.reload()
        )
      }
      toolBarRender={() => [
        <Button key="1" type="primary" onClick={onAdd}>
          新增
        </Button>,
      ]}
      request={getTfFinance}
      columns={columns}
    />
  )
}
