import React, { useEffect, useRef, useState, forwardRef } from 'react'
import {
  postTfItemFinance,
  putTfItemFinance,
  getTfItemFinanceId,
} from '@/services/tfFinanceItem'
import { Button, Card, Row, Col, Form, Input } from 'antd'
import {
  ProForm,
  ProFormDateTimeRangePicker,
  ProFormMoney,
  ProFormSelect,
  ProFormText,
  ProFormTextArea,
  ProFormRadio,
} from '@ant-design/pro-components'
import Page from '@/components/Page'
import { formItemLayout, tailFormItemLayout } from '@/utils/form'
import { useNavigate, useSearchParams } from 'react-router-dom'
import moment from 'moment'

export default (props) => {
  const formRef = useRef()
  const navigate = useNavigate()

  const [params] = useSearchParams()
  const id = params.get('id')

  useEffect(() => {
    if (id) {
      getTfItemFinanceId(id).then((res) => {
        formRef.current?.setFieldsValue(res)
      })
    }
  }, [])

  const onFinish = (values) => {
    if (!id) {
      postTfItemFinance(values).then((res) => {
        navigate(-1)
      })
    } else if (id) {
      let financeItemId = id
      putTfItemFinance(id, { financeItemId, ...values }).then((res) => {
        navigate(-1)
      })
    }
  }

  let formatter = new Intl.NumberFormat('zh-CN', {
    minimumFractionDigits: 4,
    maximumFractionDigits: 4,
  })

  return (
    <Page>
      <Card>
        <ProForm
          formRef={formRef}
          onFinish={onFinish}
          layout="horizontal"
          {...formItemLayout}
          // grid={true}
          submitter={{
            render: (_, doms) => [
              <Row>
                <Col offset={8}>
                  <Button type="primary" htmlType="submit">
                    提交
                  </Button>
                </Col>
                <Col offset={1}>
                  <Button onClick={() => navigate(-1)}>返回</Button>
                </Col>
              </Row>,
            ],
          }}
        >
          <ProFormText name="itemType" label="明细类型" />
          <ProFormText name="ycItemName" label="收支项目名称" />
          <ProFormMoney name="money" label="金额" />
          <ProFormText name="fromOrg" label="来源机构" />
          <ProFormText name="toOrg" label="目的机构" />
          <ProFormText name="attach" label="附件" />
          <ProFormRadio.Group name="ycType" label="收支类型" />
        </ProForm>
      </Card>
    </Page>
  )
}
