import React, {
  forwardRef,
  useEffect,
  useImperativeHandle,
  useRef,
  useState,
} from "react";
import {
  ProForm,
  ProFormSelect,
  ProFormText,
} from "@ant-design/pro-components";
import { Modal } from "antd";
import { postTaPackageItem, putTaPackageItem } from "@/services/taPackageItem";
import { getTaPackage } from "@/services/taPackage";
const LAYOUT_TYPE_HORIZONTAL = "horizontal";
const formItemLayout = {
  labelCol: { span: 4 },
  wrapperCol: { span: 14 },
};
export default forwardRef((props, ref) => {
  const { curd, open, setOpen } = props;
  const formRef = useRef();
  const [packageList, setPackageList] = useState();
  console.log(ref);
  const onFinish = (values) => {
    console.log(ref);
    if (curd != "new") {
      // 修改
      putTaPackageItem(curd?.packageItemId, values)
        .then(() => {
          setOpen(false);
          ref?.current?.reload();
        })
        .catch((e) => ref?.current?.reload());
    } else {
      // 新增
      postTaPackageItem(values)
        .then(() => {
          setOpen(false);
          ref?.current?.reload();
        })
        .catch((e) => ref?.current?.reload());
    }
  };

  useEffect(() => {
    formRef.current?.resetFields();

    if (curd != "new" && curd) {
      formRef.current?.setFieldsValue(curd);
    }
  }, [curd]);

  useEffect(() => {
    getTaPackage({ pageSize: 9999 })
      .then((res) => {
        const data = (res.records || []).map((it) => {
          return {
            label: it.packageName,
            value: it.packageId,
          };
        });
        setPackageList(data);
      })
      .catch((err) => {});
  }, []);

  return (
    <Modal
      title="套餐内容维护"
      open={open}
      footer={null}
      maskClosable={false}
      onCancel={() => setOpen(false)}
    >
      <ProForm
        {...formItemLayout}
        layout={LAYOUT_TYPE_HORIZONTAL}
        formRef={formRef}
        onFinish={onFinish}
        submitter={{
          render: (_, doms) => [
            doms.find((dom) => dom.props?.children === "提交"),
          ],
        }}
      >
        <ProFormText name="itemName" label="项目名称" />
        <ProFormText name="charge" label="金额" />
        <ProFormSelect
          name="packageId"
          label="套餐项目"
          options={packageList}
        />
      </ProForm>
    </Modal>
  );
});
