import React, { useEffect, useRef, useState } from 'react'
import { getTfFinance } from '@/services/tfFinance'
import { Button, Card, Row, Col } from 'antd'
import { ProTable } from '@ant-design/pro-components'
import { queryTable } from '@/utils/request'
import FinanceModalForm from './FinanceModalForm'

const tfFinanceList = queryTable(getTfFinance)

export default (props) => {
  const actionRef = useRef()
  const [open, setOpen] = useState(false)

  const columns = [
    {
      title: '记录名称',
      dataIndex: 'financeName',
      ellipsis: true,
    },
    {
      title: '项目状态',
      dataIndex: 'bizStatus',
      valueEnum: {
        1: '正常',
        0: '禁用',
      },
      search: false,
      ellipsis: true,
    },
    {
      title: '总费用',
      dataIndex: 'totalCharges',
      search: false,
      ellipsis: true,
    },
    {
      title: '毛利润',
      dataIndex: 'grossProfits',
      search: false,
      ellipsis: true,
    },
    {
      title: '总成本',
      dataIndex: 'totalCost',
      search: false,
      ellipsis: true,
    },
    {
      title: '已支出',
      dataIndex: 'expense',
      search: false,
      ellipsis: true,
    },
    {
      title: '已收款',
      dataIndex: 'received',
      search: false,
      ellipsis: true,
    },
    {
      title: '尾款',
      dataIndex: 'balancePayment',
      search: false,
      ellipsis: true,
    },
    {
      title: '发票',
      dataIndex: 'invoice',
      search: false,
      ellipsis: true,
    },
  ]

  const onAdd = () => {
    setOpen(true)
  }
  const onCancel = () => {
    setOpen(false)
  }
  return (
    <Card title={<div style={{ fontWeight: 'bold' }}>收付款信息</div>}>
      <ProTable
        toolBarRender={() => [
          <Button key="1" type="primary" onClick={onAdd}>
            新增
          </Button>,
        ]}
        // title={() => {
        //   return (
        //     <div style={{ fontWeight: 'bold', fontSize: '16px' }}>
        //       收付款信息
        //     </div>
        //   )
        // }}
        options={false}
        actionRef={actionRef}
        rowKey="financeId"
        request={tfFinanceList}
        columns={columns}
      />
      <FinanceModalForm open={open} onCancel={onCancel} actionRef={actionRef} />
    </Card>
  )
}
