import React, { useEffect, useRef, useState } from 'react'
import { Form } from 'antd'
import { postTfFinance } from '@/services/tfFinance'
import {
  ModalForm,
  ProFormText,
  ProFormMoney,
  ProFormRadio,
} from '@ant-design/pro-components'

export default (props) => {
  const { open, onCancel, actionRef } = props
  const [form] = Form.useForm()

  const onFinish = (values) => {
    postTfFinance(values).then((res) => {
      onCancel()
      actionRef.current.reload()
    })
  }
  return (
    <ModalForm
      form={form}
      title="收付款维护"
      open={open}
      grid={true}
      labelCol={{ sm: 3 }}
      layout="horizontal"
      onFinish={onFinish}
      initialValues={{ bizStatus: '1' }}
      modalProps={{
        destroyOnClose: true,
        onCancel: onCancel,
      }}
    >
      <ProFormText name="financeName" label="记录名称" />
      <ProFormMoney name="totalCharges" label="总费用" />
      <ProFormMoney name="grossProfits" label="毛利润" />
      <ProFormMoney name="totalCost" label="总成本" />
      <ProFormMoney name="expense" label="已支出" />
      <ProFormMoney name="received" label="已收款" />
      <ProFormMoney name="balancePayment" label="尾款" />
      <ProFormMoney name="invoice" label="发票" />
      <ProFormRadio.Group
        name="bizStatus"
        label="项目状态"
        options={[
          { label: '正常', value: '1' },
          { label: '禁用', value: '0' },
        ]}
      />
    </ModalForm>
  )
}
