import React, { useEffect, useRef, useState, forwardRef } from 'react'
import {
  postTaProject,
  putTaProject,
  getTaProjectId,
} from '@/services/taProject'
import { getTaCustom } from '@/services/taCustom'
import { Button, Card, Row, Col, Form, Input } from 'antd'
import {
  ProForm,
  ProFormDateTimeRangePicker,
  ProFormMoney,
  ProFormSelect,
  ProFormText,
  ProFormTextArea,
  ProFormRadio,
} from '@ant-design/pro-components'
import { useNavigate, useSearchParams } from 'react-router-dom'
import moment from 'moment'

export default (props) => {
  const { setCustomId } = props
  const formRef = useRef()
  const inputRef = useRef()
  const navigate = useNavigate()

  const [params] = useSearchParams()
  const id = params.get('id')
  const [customSelect, setCustomSelect] = useState()

  useEffect(() => {
    if (id) {
      getTaProjectId(id).then((res) => {
        formRef.current?.setFieldsValue({
          ...res,
          time: [moment(res.startTime), moment(res.endTime)],
        })
        setCustomId(res?.customId)
      })
    }

    //所属客户下拉
    getTaCustom().then((res) => {
      setCustomSelect(
        res.records?.map(
          (x) =>
            ({
              label: x.customName,
              value: x.customId,
            } || [])
        )
      )
    })
  }, [])

  const onFinish = (values) => {
    const data = {
      ...values,
      startTime: values.time[0],
      endTime: values.time[1],
    }

    if (!id) {
      postTaProject(data).then((res) => {})
    } else if (id) {
      putTaProject(id, data).then((res) => {})
    }
  }

  let formatter = new Intl.NumberFormat('zh-CN', {
    minimumFractionDigits: 4,
    maximumFractionDigits: 4,
  })

  const MyInput = forwardRef((props, ref) => {
    return (
      console.log('ref', ref),
      (
        // console.log('ref?.current', ref?.current),
        <ProFormText
          {...props}
          fieldRef={ref?.current?.focus({ cursor: 'start' })}
        />
      )
    )
  })

  // useEffect(() => {
  //   inputRef?.current?.focus({ cursor: 'start' })
  // }, [inputRef])

  return (
    <Card
      title={<div style={{ fontWeight: 'bold' }}>项目维护</div>}
      style={{
        marginRight: '24px',
        marginBottom: '24px',
        paddingBottom: '26px',
      }}
    >
      <ProForm
        formRef={formRef}
        onFinish={onFinish}
        layout="horizontal"
        initialValues={{ status: 1 }}
        grid={true}
        submitter={{
          render: (_, doms) => [
            <Row justify="center">
              <Col>
                <Button type="primary" htmlType="submit">
                  提交
                </Button>
              </Col>
              <Col offset={1}>
                <Button onClick={() => navigate('/project')}>返回</Button>
              </Col>
            </Row>,
          ],
        }}
      >
        <MyInput
          colProps={{ xl: 12 }}
          labelCol={{ sm: 4 }}
          name="partyA"
          label="甲方"
          fieldProps={{ ref: inputRef }}
          ref={inputRef}
        />
        {/* <Form.Item
          wrapperCol={{ xs: 16 }}
          labelCol={{ span: 8 }}
          name="partyA"
          label="甲方"
        >
          <Input ref={inputRef?.current?.focus({ cursor: 'start' })} />
        </Form.Item> */}
        <ProFormText colProps={{ xl: 12 }} name="partyAName" label="甲方名称" />
        <ProFormText
          colProps={{ xl: 12 }}
          labelCol={{ sm: 4 }}
          name="partyB"
          label="乙方"
        />
        <ProFormText colProps={{ xl: 12 }} name="partyBName" label="乙方名称" />
        <ProFormText
          colProps={{ xl: 12 }}
          name="projectName"
          label="项目名称"
        />
        <ProFormSelect
          colProps={{ xl: 12 }}
          options={customSelect}
          name="customId"
          label="所属客户"
        />
        <ProFormMoney colProps={{ xl: 12 }} name="quotation" label="合同报价" />
        <ProFormMoney
          colProps={{ xl: 12 }}
          labelCol={{ sm: 4 }}
          name="receivedMoney"
          label="已收款"
        />
        <ProFormMoney
          colProps={{ xl: 12 }}
          name="invoicedMoney"
          label="已开票额"
        />
        <ProFormSelect
          colProps={{ xl: 12 }}
          name="stageName"
          label="阶段名称"
          options={[
            { label: '未开始', value: '0' },
            { label: '处理中', value: '1' },
            { label: '已完成', value: '2' },
          ]}
        />
        <ProFormRadio.Group
          colProps={{ xl: 12 }}
          name="status"
          label="项目状态"
          options={[
            { label: '正常', value: 1 },
            { label: '禁用', value: 0 },
          ]}
        />
        <ProFormDateTimeRangePicker
          colProps={{ xl: 12 }}
          name="time"
          label="工作周期"
        />
        <ProFormTextArea name="introduction" label="项目简介" />
      </ProForm>
    </Card>
  )
}
