import React, { useEffect, useRef, useState } from 'react'
import { getTaProjectNode } from '@/services/taProjectNode'
import { Button, Card, Row, Col } from 'antd'
import { queryTable } from '@/utils/request'
import { ProTable } from '@ant-design/pro-components'
import ProjectNodeModalForm from './ProjectNodeModalForm'
import moment from 'moment'

const projectNodeList = queryTable(getTaProjectNode)

export default (props) => {
  const actionRef = useRef()
  const [open, setOpen] = useState(false)

  const onAdd = () => {
    setOpen(true)
  }
  const onCancel = () => {
    setOpen(false)
  }

  const columns = [
    {
      title: '跟进状态',
      dataIndex: 'bizStatus',
      ellipsis: true,
    },
    {
      title: '备注',
      dataIndex: 'remark',
      ellipsis: true,
    },
    {
      title: '业务发生时间',
      dataIndex: 'bizDate',
      render: (t) => moment(t).format('YYYY-MM-DD'),
      ellipsis: true,
    },
  ]

  return (
    <Card
      title={<div style={{ fontWeight: 'bold' }}>跟进信息</div>}
      style={{ marginTop: '24px' }}
    >
      <ProTable
        toolBarRender={() => [
          <Button key="1" type="primary" onClick={onAdd}>
            新增
          </Button>,
        ]}
        options={false}
        search={false}
        actionRef={actionRef}
        rowKey="nodeId"
        request={projectNodeList}
        columns={columns}
      />
      <ProjectNodeModalForm
        open={open}
        onAdd={onAdd}
        onCancel={onCancel}
        actionRef={actionRef}
      />
    </Card>
  )
}
