import List from '@/components/Page/List'
import React, { useRef } from 'react'
import { getTaProject, deleteTaProject } from '@/services/taProject'
import { getTaCustom } from '@/services/taCustom'
import { queryDict } from '@/utils/request'
import { Button, ConfigProvider } from 'antd'
import zhCN from 'antd/es/locale/zh_CN'
import { ProFormDateTimeRangePicker } from '@ant-design/pro-components'
import { useNavigate } from 'react-router-dom'
import moment from 'moment'
import './zh-cn.js'

export default (props) => {
  const navigate = useNavigate()
  const queryCustom = queryDict(getTaCustom, {
    labelKey: 'customName',
    valueKey: 'customId',
  })

  const columns = [
    {
      title: '项目日期',
      dataIndex: 'startTime1',
      search: {
        transform: (value) => {
          return {
            startTime: value[0],
            endTime: value[1],
          }
        },
      },
      valueType: 'dateRange',
      hideInTable: true,
    },
    {
      title: '甲方',
      dataIndex: 'partyA',
      search: false,
    },
    {
      title: '甲方名称',
      dataIndex: 'partyAName',
    },
    {
      title: '乙方',
      dataIndex: 'partyB',
      search: false,
    },
    {
      title: '乙方名称',
      dataIndex: 'partyBName',
    },
    {
      title: '项目名称',
      dataIndex: 'projectName',
    },
    {
      title: '项目简介',
      dataIndex: 'introduction',
      search: false,
    },
    {
      title: '项目开始日期',
      dataIndex: 'startTime',
      render: (t) => moment(t).format('YYYY-MM-DD'),
      search: false,
    },
    {
      title: '项目结束日期',
      dataIndex: 'endTime',
      render: (t) => moment(t).format('YYYY-MM-DD'),
      search: false,
    },
    {
      title: '合同报价',
      dataIndex: 'quotation',
      search: false,
    },
    {
      title: '已收款',
      dataIndex: 'receivedMoney',
      search: false,
    },
    {
      title: '已开票额',
      dataIndex: 'invoicedMoney',
      search: false,
    },
    {
      title: '阶段名称',
      dataIndex: 'stageName',
      search: false,
      valueEnum: {
        0: '未开始',
        1: '处理中',
        2: '已完成',
      },
    },
    {
      title: '状态',
      dataIndex: 'status',
      valueEnum: {
        0: '禁用',
        1: '正常',
      },
      search: false,
    },

    // {
    //   title: '创建时间',
    //   dataIndex: 'createdAt',
    // },
    // {
    //   title: '创建人',
    //   dataIndex: 'createdBy',
    //   search: false,
    // },
    {
      title: '所属客户',
      dataIndex: 'customId',
      valueType: 'select',
      request: queryCustom,
      search: false,
    },
    // {
    //   title: '删除标志',
    //   dataIndex: 'deleted',
    // },
    // {
    //   title: '阶段ID',
    //   dataIndex: 'stageId',
    // },
    // {
    //   title: '租户号',
    //   dataIndex: 'tenantId',
    // },
    // {
    //   title: '更新时间',
    //   dataIndex: 'updatedAt',
    // }
  ]

  const actionRef = useRef()
  const onAdd = () => {
    navigate('/project/edit')
  }
  return (
    <ConfigProvider locale={zhCN}>
      <List
        scroll={{ x: 1800 }}
        actionRef={actionRef}
        rowKey="projectId"
        onEdit={(record) => navigate(`/project/edit?id=${record.projectId}`)}
        onDelete={(record) =>
          deleteTaProject(record.projectId).then(() =>
            actionRef.current.reload()
          )
        }
        toolBarRender={() => [
          <Button key="1" type="primary" onClick={onAdd}>
            新增
          </Button>,
        ]}
        request={getTaProject}
        columns={columns}
      />
    </ConfigProvider>
  )
}
