import React, { useEffect, useRef, useState, forwardRef } from 'react'
import {
  postTaProjectContact,
  putTaProjectContact,
  getTaProjectContactId,
} from '@/services/taProjectContact'
import { Button, Card, Row, Col, Form, Input } from 'antd'
import {
  ProForm,
  ProFormDateTimeRangePicker,
  ProFormDatePicker,
  ProFormMoney,
  ProFormSelect,
  ProFormText,
  ProFormTextArea,
  ProFormRadio,
} from '@ant-design/pro-components'
import Page from '@/components/Page'
import { formItemLayout, tailFormItemLayout } from '@/utils/form'
import { useNavigate, useSearchParams } from 'react-router-dom'
import moment from 'moment'

export default (props) => {
  const formRef = useRef()
  const navigate = useNavigate()

  const [params] = useSearchParams()
  const id = params.get('id')

  useEffect(() => {
    if (id) {
      getTaProjectContactId(id).then((res) => {
        formRef.current?.setFieldsValue(res)
      })
    }
  }, [])

  const onFinish = (values) => {
    if (!id) {
      postTaProjectContact(values).then((res) => {
        navigate(-1)
      })
    } else if (id) {
      let personId = id
      putTaProjectContact(id, { personId, ...values }).then((res) => {
        navigate(-1)
      })
    }
  }

  let formatter = new Intl.NumberFormat('zh-CN', {
    minimumFractionDigits: 4,
    maximumFractionDigits: 4,
  })

  return (
    <Page>
      <Card>
        <ProForm
          formRef={formRef}
          onFinish={onFinish}
          layout="horizontal"
          initialValues={{ isDefault: 0 }}
          {...formItemLayout}
          submitter={{
            render: (_, doms) => [
              <Row>
                <Col offset={8}>
                  <Button type="primary" htmlType="submit">
                    提交
                  </Button>
                </Col>
                <Col offset={1}>
                  <Button onClick={() => navigate(-1)}>返回</Button>
                </Col>
              </Row>,
            ],
          }}
        >
          <ProFormText name="personName" label="名称" />
          <ProFormSelect
            name="sex"
            label="性别"
            options={[
              { label: '男', value: 1 },
              { label: '女', value: 2 },
              { label: '未知', value: 9 },
            ]}
          />
          <ProFormText name="age" label="年龄" />
          <ProFormText name="phone" label="手机号" />
          <ProFormText name="email" label="邮箱" />
          <ProFormText name="position" label="职位" />
          <ProFormDatePicker name="birthDay" label="生日" />
          <ProFormRadio.Group
            name="isDefault"
            label="是否默认联系人"
            options={[
              { label: '是', value: 1 },
              { label: '否', value: 0 },
            ]}
          />
        </ProForm>
      </Card>
    </Page>
  )
}
