import React from 'react';
import { Button, Card, Tree, message, Row, Col } from "antd";
import useBool from "@/utils/hooks/useBool";
import {
  getSysRoleResources,
  postSysRoleResources
} from "@/services/sysroleresources";
import Menus from './menus';
import Btn from './components/Btn';

export default (props) => {
  const { role } = props;

  const title = role ? `${role.roleName} - 授权菜单` : "未选角色 - 授权菜单";
  const [loading, startLoading, cancelLoading] = useBool();
  const [menus, setMenus] = React.useState([]);
  const [buttons, setButtons] = React.useState([]);
  const [currentMenu, setCurrentMenu] = React.useState();
  
// 获取授权数据
React.useEffect(() => {
  setCurrentMenu()

  if (!role?.roleId) {
    setMenus([])
    setButtons([])
  } else {
    getSysRoleResources(role.roleId).then(res => {
      const mnus = [];
      const btns = [];

      for (let item of res) {
        if (item.resourceType == 'menu') {
          mnus.push(item);
        } else {
          btns.push(item);
        }
      }

      setMenus(mnus);
      setButtons(btns);
    });
  }
}, [role?.roleId]);

  const onSubmit = () => {
    // 如果一个都不选，代表清空授权
    const data = [...menus, ...buttons];
    startLoading();
    postSysRoleResources(role?.roleId, data)
      .then((res) => {
        cancelLoading();
      })
      .catch(() => {
        cancelLoading();
      });
  };

  

  return (
    <Card
      title={title}
      extra={
        <Button
          type="primary"
          ghost
          loading={loading}
          disabled={!role?.roleId}
          onClick={onSubmit}
        >
          保存
        </Button>
      }
    >
      <Row>
        <Col span={12}>
          <Menus roleId={role?.roleId} value={menus} onChange={setMenus} onMenuChange={setCurrentMenu} />
        </Col>
        {/* <Col span={12}>
          <Btn roleId={role?.roleId} menuId={currentMenu} value={buttons} onChange={setButtons} />
        </Col> */}
      </Row>
    </Card>
  )
}
