import React from "react";
import { Card, Checkbox } from "antd";
import { useModel } from "@/store";

export default (props) => {
  const { roleId, menuId, value, onChange } = props;
  const { dbButtons } = useModel("user");

  const [checked, setChecked] = React.useState([]);

  // 分离出当前菜单的按钮
  const [inMenus, notInMenus] = React.useMemo(() => {
    if (!dbButtons || !dbButtons.length) return [[],[]];
    return dbButtons.reduce((acc, btn) => {
      const [a1, a2] = acc;

      if (btn.menuId == menuId) {
        a1.push(btn.buttonId);
      } else {
        a2.push(btn.buttonId);
      }
      return acc;
    }, [[],[]]);
  }, [dbButtons, menuId]);

  // 生成 checkbox 选项
  const options = React.useMemo(() => {
    if (!dbButtons || !dbButtons.length) return [];
    return dbButtons.filter(x => x.menuId == menuId).map(x => ({ label: x.buttonName, value: x.buttonId }))
  }, [dbButtons, menuId]);

  const handleChange = (values) => {
    setChecked(values)
    
    // 触发 change 事件
    const allKeys = [...notInMenus, ...values]
    onChange && onChange(allKeys.map(x => ({ roleId, resourceId: x, resourceType: 'buttons' })));
  }

  React.useEffect(() => {
    if (!value || !value.length) return;

    const keys = [];
    for (let item of value) {
      if (inMenus.includes(item.resourceId)) {
        keys.push(item.resourceId);
      }
    }

    setChecked(keys);
  }, [value, inMenus]);

  return (
    <Card title="按钮">
      <Checkbox.Group
        disabled={!roleId}
        options={options}
        value={checked}
        onChange={handleChange}
      />
    </Card>
  );

}