import React from "react";
import { Button, Card, Tree, message, Row, Col } from "antd";
import { useModel } from "@/store";
import { arr2Tree } from "@/utils/array";
import styles from './style.module.less';

export default (props) => {
  const { roleId, value, onChange, onMenuChange } = props;

  const { dbMenus } = useModel("user");
  const [expandedKeys, setExpandedKeys] = React.useState([]);
  // console.log(dbMenus)
  const treeData = React.useMemo(() => {
    // 先转为需要的格式
    const arr = dbMenus.map((x) => ({
      title: x.menuName,
      key: x.menuId,
      parentId: x.parentId,
    }));
    // 再转为 tree
    const [tree] = arr2Tree(arr);

    return tree;
  }, [dbMenus]);

  React.useEffect(() => {
    // 默认展开全部菜单
    // setExpandedKeys(dbMenus.map(x => x.menuId))
  }, [dbMenus]);

  const [checkedKeys, setCheckedKeys] = React.useState({
    checked: [],
    halfChecked: [],
  });

  const onCheck = (keys, { node, halfCheckedKeys }) => {
    setCheckedKeys({ checked: keys, halfChecked: halfCheckedKeys });

    // 触发 change 事件
    const allChecked = [...keys];
    if (!allChecked || allChecked.length < 1) {
      onChange && onChange([]);
      return;
    }

    allChecked.push(...halfCheckedKeys);
    console.log("--------allChecked-------", allChecked, halfCheckedKeys);

    const newList = [];
    for (let menuId of allChecked) {
      const menuItem = dbMenus.find((x) => x.menuId == menuId);
      if (menuItem) {
        newList.push({ roleId, resourceId: menuId, resourceType: "menu" });
      }
    }

    onChange && onChange(newList);
  };

  React.useEffect(() => {
    const keys = { checked: [], halfChecked: [] };

    if (!dbMenus && dbMenus.length < 1) {
      setCheckedKeys(keys);
      return;
    }

    if (!value || !value.length) {
      setCheckedKeys(keys);
    } else {
      const checkedKeys = value.reduce((acc, item) => {
        const { checked, halfChecked } = acc;
        const menuId = item.resourceId;

        const children = dbMenus.filter((x) => x.parentId == menuId);
        if (children.length < 1) {
          // 没有子元素说明是叶子节点
          checked.push(menuId);
        } else {
          // 验证子元素是否全部存在
          let allIn = true;
          for (let child of children) {
            const found = value.find((x) => x.resourceId == child.menuId);
            if (!found) {
              allIn = false;
              break;
            }
          }

          if (!allIn) {
            halfChecked.push(menuId);
          } else {
            checked.push(menuId);
          }
        }

        return { checked, halfChecked };
      }, keys);

      console.log("-----checkedKeys---", checkedKeys);

      setCheckedKeys(checkedKeys);
    }
  }, [value, dbMenus]);

  const onSelect = (keys, { selectedNodes, node, event }) => {
    onMenuChange && onMenuChange(keys[0]);
  };

  return (
    <Card title="菜单" className={styles.cardTree}>
      <Tree
        disabled={!roleId}
        multiple={false}
        showLine
        checkable
        autoExpandParent
        expandedKeys={expandedKeys}
        checkStrictly={false}
        checkedKeys={checkedKeys}
        onCheck={onCheck}
        onSelect={onSelect}
        onExpand={setExpandedKeys}
        treeData={treeData}
      />
    </Card>
  );
};
