import React, { useEffect } from "react";
import { postFxTenant, putFxTenant, getFxTenantId } from "@/services/fxtenant";
import { useNavigate, useSearchParams } from "react-router-dom";
import {
  ProForm,
  ProFormText,
  ProFormDateRangePicker,
  ProFormSelect,
} from "@ant-design/pro-components";
import { Card, Form } from "antd";
import Page from "@/components/Page";
import moment from "moment";
export default (props) => {
  const [form] = Form.useForm();
  const navigate = useNavigate();
  const [searchParams] = useSearchParams();
  const id = searchParams.get("id");
  useEffect(() => {
    if (id) {
      getFxTenantId(id).then((res) => {
        form.setFieldsValue({
          ...res,
          // time:[moment(res.startTime).format("YYYY-mm-dd"),moment(res.endTime).format("YYYY-mm-dd")],
          time: [res.startTime, res.endTime],
          status:
            res.status == 0 ? "未激活" : res.status == 1 ? "已激活" : "停用",
        });
      });
    }
  }, []);

  const onFinish = (values) => {
    console.log(values);
    const data = {
      ...values,
      startTime: values?.time[0],
      endTime: values?.time[1],
      status: values.status == "未激活" ? 0 : values.status == "已激活" ? 1 : 2,
    };
    if (!id) {
      postFxTenant(data).then((res) => {
        navigate(-1);
      });
    } else {
      putFxTenant(id, data).then((res) => {
        navigate(-1);
      });
    }
  };

  return (
    <Page>
      <Card>
        <ProForm form={form} onFinish={onFinish} layout="horizontal">
          <ProFormText
            name="tenantName"
            label="租户名称"
            placeholder="请输入租户名称"
            rules={[{ required: true, message: "租户名称不能为空" }]}
          />
          <ProFormDateRangePicker
            name={["time"]}
            label="合同生效时间"
            rules={[{ required: true, message: "合同生效时间不能为空" }]}
          />
          <ProFormText
            name="tenantCode"
            label="租户编号"
            placeholder="请输入租户编号"
          />

          <ProFormText
            name="manager"
            label="管理员名称"
            placeholder="请输入管理员名称"
          />
          <ProFormText
            name="phone"
            label="手机号 "
            placeholder="请输入手机号"
            rules={[{ required: true, message: "手机号不能为空" }]}

          />
          <ProFormSelect
            label="状态 "
            name="status"
            valueEnum={{
              0: "未激活",
              1: "已激活",
              2: "停用",
            }}
          />
        </ProForm>
      </Card>
    </Page>
  );
};
