import List from "@/components/Page/List";
import React from "react";

import { getFxTenant, deleteFxTenant } from "@/services/fxtenant";

import { useNavigate } from "react-router-dom";
import { Button } from "antd";
import moment from "moment";
export default (props) => {
  const navigate = useNavigate();
  const actionRef = React.useRef();
  const columns = [
    {
      title: "时间",
      dataIndex: "time",
      valueType: "dateRange",
      hideInTable: true,
      search: {
        transform: (value) => {
          return {
            startTime: value[0],
            endTime: value[1],
          };
        },
      },
    },
    {
      title: "租户编号",
      dataIndex: "tenantCode",
    },
    {
      title: "租户名称",
      dataIndex: "tenantName",
    },
    {
      title: "开始时间",
      dataIndex: "startTime",
      render: (_,row) =>row.startTime? moment(row.startTime).format("YYYY-MM-DD HH:mm") :"",
      search: false,
    },
    {
      title: "结束时间",
      dataIndex: "endTime",
      render: (_,row) =>row.endTime? moment(row.endTime).format("YYYY-MM-DD HH:mm") :"",
      search: false,
    },
    // {
    //   title: "管理人名称",
    //   dataIndex: "manager",
    // },
    {
      title: "手机号",
      dataIndex: "phone",
    },
    {
      title: "状态",
      dataIndex: "status",
      valueType: "select",
      render: (_, record) =>
        record.status == 0 ? "未激活" : record.status == 1 ? "已激活" : "停用",
      valueEnum: {
        0: "未激活",
        1: "已激活",
        2: "停用",
      },
    },
    // {
    //   title: "创建人",
    //   dataIndex: "createdBy",
    //   key: "createdBy",
    //   search: false,
    // },
    {
      title: "创建时间",
      dataIndex: "createdAt",
      key: "createdAy",
      search: false,
      render: (t) => moment(t).format("YYYY-MM-DD HH:mm:ss"),
      // new Date(t).toLocaleString("zh")
    },
    // {
    //   title: "更新人",
    //   dataIndex: "updatedBy",
    //   key: "updatedBy",
    //   search: false,
    // },
    {
      title: "更新时间",
      dataIndex: "updatedAt",
      key: "updatedAt",
      search: false,
      render: (t) => moment(t).format("YYYY-MM-DD HH:mm:ss"),
    },
  ];

  const DeleteFxUser = (record) => {
    deleteFxTenant(record.tenantId).then((res) => {
      actionRef.current.reload();
    });
  };
  return (
    <List
      rowKey="tenantId"
      actionRef={actionRef}
      request={getFxTenant}
      onEdit={(record) => navigate(`/tenant/edit?id=${record.tenantId}`)}
      onDelete={DeleteFxUser}
      toolBarRender={() => [
        <Button
          key="1"
          type="primary"
          onClick={() => {
            navigate("edit");
          }}
        >
          新增
        </Button>,
      ]}
      columns={columns}
    />
  );
};
