import {
  UserOutlined,
  SolutionOutlined,
  FileTextOutlined,
  HeartOutlined,
  HourglassTwoTone,
  StopFilled,
  UserAddOutlined,
  UsergroupAddOutlined,
  TransactionOutlined,
  PayCircleOutlined,
} from '@ant-design/icons'
import { Outlet, Navigate } from 'react-router-dom'
import AuthLayout from '@/layouts/AuthLayout'
import Login from '@/pages/login'
import Page404 from '@/pages/404'
import AdUser from '@/pages/adUser'
import AdUserEdit from '@/pages/adUser/Edit'
import Project from '@/pages/project'
import ProjectEdit from '@/pages/project/Edit'
import ProjectContact from '@/pages/projectContact'
import ProjectContactEdit from '@/pages/projectContact/Edit'
import ProjectDeploy from '@/pages/projectDeploy'
import ProjectDeployEdit from '@/pages/project/components/ProjectDeployEdit'
import ProjectNode from '@/pages/projectNode'

import Role from '@/pages/role'
import Dept from '@/pages/dept'
import Package from '@/pages/package'
import PackageEdit from '@/pages/package/Edit'
import Member from '@/pages/member'
import MemberEdit from '@/pages/member/Edit'
import Custom from '@/pages/custom'
import CustomEdit from '@/pages/custom/Edit'
import Finance from '@/pages/finance'
import FinanceEdit from '@/pages/finance/Edit'
import FinanceItem from '@/pages/financeItem'
import FinanceItemEdit from '@/pages/financeItem/Edit'
import Tenant from '@/pages/tenant'
import TenantEdit from '@/pages/tenant/Edit'

// import RoleEdit from "@/pages/role/Edit";
/**
 * meta 用来扩展自定义数据数据
 * {
 *    title: 用于页面或者菜单的标题, 没有此字段, 菜单不会显示
 *    hideInMenu: 布尔值, 如果为 false, 菜单不会显示
 *    noLayout: 布尔值, 如果为 true, 将不会使用默认布局
 *    noSiderBar: 布尔值, 如果为 true, 将没有左侧菜单栏
 *    noFooter: 布尔值, 如果为 true, 将没有底部 footer
 *    target: 字符串, 如果为 _blank, 将在新窗口打开
 *    permission: 对应服务器端权限名称
 * }
 */

export const authRoutes = [
  {
    // index: true,
    element: <Navigate to="/aduser" replace={true} />,
  },
  {
    path: 'aduser',
    element: <AdUser />,
    meta: {
      title: '用户管理',
      icon: <SolutionOutlined />,
    },
  },
  {
    path: 'aduser/edit',
    element: <AdUserEdit />,
    meta: {
      title: '用户维护',
      hideInMenu: true,
    },
  },
  {
    path: 'project',
    element: <Project />,
    meta: {
      title: '项目管理',
      icon: <FileTextOutlined />,
    },
  },
  {
    path: 'project/edit',
    element: <ProjectEdit />,
    meta: {
      title: '项目维护',
      hideInMenu: true,
    },
  },
  {
    path: 'projectDeploy/edit',
    element: <ProjectDeployEdit />,
    meta: {
      title: '部署维护',
      hideInMenu: true,
    },
  },
  {
    path: 'projectContact',
    element: <ProjectContact />,
    meta: {
      title: '项目联系人管理',
      icon: <UserAddOutlined />,
    },
  },
  {
    path: 'projectContact/edit',
    element: <ProjectContactEdit />,
    meta: {
      title: '项目联系人维护',
      hideInMenu: true,
    },
  },
  // {
  //   path: 'projectDeploy',
  //   element: <ProjectDeploy />,
  //   meta: {
  //     title: '服务器管理',
  //     icon: <FileTextOutlined />,
  //   },
  // },
  // {
  //   path: 'projectNode',
  //   element: <ProjectNode />,
  //   meta: {
  //     title: '流程节点管理',
  //     icon: <FileTextOutlined />,
  //   },
  // },
  {
    path: 'dept',
    element: <Dept />,
    meta: {
      title: '部门管理',
      icon: <HeartOutlined />,
    },
  },
  {
    path: 'tenant',
    element: <Tenant />,
    meta: {
      title: '租户管理',
      icon: <UserOutlined />,
    },
  },
  {
    path: 'tenant/edit',
    element: <TenantEdit />,
    meta: {
      title: '租户编辑',
      hideInMenu: true,
    },
  },
  {
    path: 'role',
    element: <Role />,
    meta: {
      title: '角色管理',
      icon: <UserOutlined />,
    },
  },
  {
    path: 'custom',
    element: <Custom />,
    meta: {
      title: '客户管理',
      icon: <UsergroupAddOutlined />,
    },
  },
  {
    path: 'custom/edit',
    element: <CustomEdit />,
    meta: {
      title: '客户维护',
      hideInMenu: true,
    },
  },

  {
    path: 'package',
    element: <Package />,
    meta: {
      title: '套餐管理',
      icon: <HourglassTwoTone />,
    },
  },
  {
    path: 'package/edit',
    element: <PackageEdit />,
    meta: {
      title: '套餐维护',
      hideInMenu: true,
    },
  },
  {
    path: 'member',
    element: <Member />,
    meta: {
      title: '会员管理',
      icon: <HourglassTwoTone />,
    },
  },
  {
    path: 'member/edit',
    element: <MemberEdit />,
    meta: {
      title: '会员管理',
      hideInMenu: true,
    },
  },
  {
    path: 'finance',
    element: <Finance />,
    meta: {
      title: '公司财务管理',
      icon: <TransactionOutlined />,
    },
  },
  {
    path: 'finance/edit',
    element: <FinanceEdit />,
    meta: {
      title: '财务维护',
      hideInMenu: true,
    },
  },
  {
    path: 'financeItem',
    element: <FinanceItem />,
    meta: {
      title: '收付款管理',
      icon: <PayCircleOutlined />,
    },
  },
  {
    path: 'financeItem/edit',
    element: <FinanceItemEdit />,
    meta: {
      title: '收付款维护',
      hideInMenu: true,
    },
  },
]

export const defaultRoutes = [
  {
    path: '/',
    element: <AuthLayout />,
    children: [
      {
        path: '*',
        element: <Page404 />,
      },
    ],
  },
  {
    path: '/login',
    element: <Login />,
  },
  {
    path: '*',
    element: <Page404 />,
  },
]

export function mergeAuthRoutes(r1, r2) {
  const r = r1.slice()
  const children = r1[0].children.slice()
  r[0].children = children.concat(r2)
  return r
}

// 全部路由
export const routes = mergeAuthRoutes(defaultRoutes, authRoutes)
function getPath(parent = '/', current = '') {
  if (current.indexOf('/') === 0 || current.indexOf('http') === 0)
    return current
  return `${parent}/${current}`.replace(/\/\//g, '/')
}

// 路由数组, 一维数组
export const routeArr = (() => {
  const flatten = (routes, parentPath = '/') => {
    return routes.reduce((acc, route) => {
      const path = getPath(parentPath, route.path)
      const children = route.children ? flatten(route.children, path) : []

      return acc.concat([{ ...route, path }].concat(children))
    }, [])
  }

  return flatten(routes)
})()
